summaryrefslogtreecommitdiffstats
path: root/src/mtab.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mtab.h')
-rw-r--r--src/mtab.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mtab.h b/src/mtab.h
index ca4372c..d99d78f 100644
--- a/src/mtab.h
+++ b/src/mtab.h
@@ -43,12 +43,12 @@ const char *bfs_fstype(const struct bfs_mtab *mtab, const struct bfs_stat *statb
*
* @param mtab
* The current mount table.
* @param path
* The path to check.
* @return
* Whether the named file could be a mount point.
*/
-bool bfs_might_be_mount(const struct bfs_mtab *mtab, const char *path);
+bool bfs_might_be_mount(const struct bfs_mtab *mtab, const char *name);
/**
* Free a mount table.
@@ -43,12 +43,12 @@ const char *bfs_fstype(const struct bfs_mtab *mtab, const struct bfs_stat *statb
* @param mtab
* The current mount table.
- * @param path
- * The path to check.
+ * @param name
+ * The name of the file to check.
* @return
* Whether the named file could be a mount point.